BaseBean class

Constructors

BaseBean({double xyLineWidth = 2, Color xColor = defaultColor, Color yColor = defaultColor, bool isShowBorderTop = false, bool isShowBorderRight = false, required List<DialStyleY> yDialValues, bool yDialLeftMain = true, bool isShowX = true, double yMax = 100.0, double yMin = 0.0, EdgeInsets basePadding = defaultBasePadding, bool isShowHintX = false, bool isShowHintY = false, Color hintLineColor = defaultColor, double hintLineWidth = 1.0, bool isHintLineImaginary = false, bool isShowXScale = false, bool isShowYScale = false, double rulerWidth = 4, List<UnitXY>? units, double? xBaseLineY})

Properties

basePadding ↔ EdgeInsets
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hintLineColor ↔ Color
getter/setter pair
hintLineWidth ↔ double
getter/setter pair
isHintLineImaginary ↔ bool
getter/setter pair
isShowBorderRight ↔ bool
getter/setter pair
isShowBorderTop ↔ bool
getter/setter pair
isShowHintX ↔ bool
getter/setter pair
isShowHintY ↔ bool
getter/setter pair
isShowX ↔ bool
getter/setter pair
isShowXScale ↔ bool
getter/setter pair
isShowYScale ↔ bool
getter/setter pair
rulerWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
units ↔ List<UnitXY>?
getter/setter pair
xBaseLineY ↔ double?
x轴在y轴上的数值,不设置表示x轴在坐标系的最底部(如果不为空,则按照此数值在yMax和yMin之间的占比对应位置绘制一条水平线)
getter/setter pair
xColor ↔ Color
getter/setter pair
xyLineWidth ↔ double
getter/setter pair
yAdmissSecValue → double
no setter
yColor ↔ Color
getter/setter pair
yDialLeftMain ↔ bool
getter/setter pair
yDialValues ↔ List<DialStyleY>
getter/setter pair
yMax ↔ double
getter/setter pair
yMin ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited