DialStyleY class

Constructors

DialStyleY({Color? hintLineColor, List<Color>? fillColors, DialStyleYSub? leftSub, DialStyleYSub? rightSub, required double yValue, required double positionRetioy})

Properties

fillColors ↔ List<Color>?
目前只对ChartLineFocus有效,其他图表暂时无意义 如果FocusChartBeanMain中的参数gradualColors参数设置为null的时候,区间渐变从此区间顶topcenter,到区间底部bottomcenter的LinearGradient颜色填充。如果不设置则默认此区间y轴副文本颜色,bottomcenter为此区间y轴副文本颜色的0.3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hintLineColor ↔ Color?
如果有辅助线的时候,需要特殊设置的辅助线颜色,这个参数对标baseBean模型参数中的hintLineColor,这里不为空的以后,这个positionRetioy的辅助线颜色设置以此为准
getter/setter pair
leftSub ↔ DialStyleYSub?
getter/setter pair
positionRetioy ↔ double
这个也和centerSubTitle有关(比如:1.0和最近的下一个比率0.5之间的居中副标题取的是positionRetioy为1.0的副标题)
getter/setter pair
rightSub ↔ DialStyleYSub?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
yValue ↔ double
y轴值,用以计算绘制点落的区间比较使用,在区间放大的折线图中体现
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited