DialStyleYSub class

Constructors

DialStyleYSub({String title = '', TextStyle titleStyle = defaultTextStyle, String centerSubTitle = '', TextStyle centerSubTextStyle = defaultTextStyle})

Properties

centerSubTextStyle ↔ TextStyle
getter/setter pair
centerSubTitle ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
titleStyle ↔ TextStyle
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited