HintEdgeInset class

Properties

bottom → PointHintParam?
final
hashCode → int
The hash code for this object.
no setterinherited
left → PointHintParam?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → PointHintParam?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const HintEdgeInset