ChartBarBeanXCell class

Constructors

ChartBarBeanXCell({num? value, String rectTopText = '', TextStyle rectTopTextStyle = defaultTextStyle, List<SectionColor>? sectionColors})

Properties

hashCode → int
The hash code for this object.
no setterinherited
rectTopText ↔ String
getter/setter pair
rectTopTextStyle ↔ TextStyle
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionColors ↔ List<SectionColor>?
getter/setter pair
value ↔ num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited