TouchSet class

Constructors

TouchSet({bool outsidePointClear = true, SelectModelSet selelctSet = SelectModelSet.normal, BarPointBack? touchBack})

Properties

hashCode → int
The hash code for this object.
no setterinherited
outsidePointClear → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selelctSet → SelectModelSet
final
touchBack → BarPointBack?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited