BarTouchCellModel class

Constructors

BarTouchCellModel({required Offset begainPoint, required Size size, required int index, dynamic param})

Properties

begainPoint ↔ Offset
getter/setter pair
centerX → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
param ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited