ChartLineBarBeanSystem class

Constructors

ChartLineBarBeanSystem({double lineWidth = 2, required List<LineBarSectionBean> lineBarBeans, Color? lineColor, LineColorSegmentationModel? segmentationModel, bool enableTouch = false})

Properties

enableTouch ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineBarBeans ↔ List<LineBarSectionBean>
getter/setter pair
lineColor ↔ Color?
线颜色 ,与参数segmentationModel互斥
getter/setter pair
lineWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentationModel ↔ LineColorSegmentationModel?
线条分段颜色设置,如果不为空则会覆盖lineColor效果,故此参数设置和lineColor参数互斥
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited