LineBarTouchSet class

Constructors

LineBarTouchSet({bool outsidePointClear = true, CellPointSet pointSet = CellPointSet.normal, LineBarSelectSet selelctSet = LineBarSelectSet.normal, LineBarPointBack? touchBack})

Properties

hashCode → int
The hash code for this object.
no setterinherited
outsidePointClear → bool
final
pointSet → CellPointSet
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selelctSet → LineBarSelectSet
final
touchBack → LineBarPointBack?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited