PointModel class

Constructors

PointModel({required Offset offset, CellPointSet cellPointSet = CellPointSet.normal, Color? sectionColor})

Properties

cellPointSet ↔ CellPointSet
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ Offset
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionColor ↔ Color?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited