DimensionBGSet class

Constructors

DimensionBGSet({bool isCircle = false, List<DimensionBgCircleLine>? circleLines, double dimensionLineWidth = 0, Color dimensionLineColor = defaultColor, bool dimensionLineHintLineImaginary = false, double extensionRadius = 10})
DimensionBGSet.normalSet({bool isCircle = false, List<DimensionBgCircleLine>? circleLines, double dimensionLineWidth = 0, Color dimensionLineColor = defaultColor, bool dimensionLineHintLineImaginary = false, double extensionRadius = 10})
const

Properties

circleLines → List<DimensionBgCircleLine>?
final
dimensionLineColor → Color
final
dimensionLineHintLineImaginary → bool
final
dimensionLineWidth → double
final
extensionRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
isCircle → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

normal → const DimensionBGSet