DimensionBgCircleLine class

Constructors

DimensionBgCircleLine({double lineWidth = 1, Color lineColor = defaultColor, bool isHintLineImaginary = false})
DimensionBgCircleLine.normalSet({double lineWidth = 1, Color lineColor = defaultColor, bool isHintLineImaginary = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isHintLineImaginary → bool
final
lineColor → Color
final
lineWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

normal → const DimensionBgCircleLine