DimensionCellModel class

Constructors

DimensionCellModel({double value = 0, PointType pointType = PointType.Rectangle, Size pointSize = Size.zero, Radius pointRadius = Radius.zero, List<Color>? pointShaderColors, Image? placehoderImage, Size placeImageSize = Size.zero})

Properties

hashCode → int
The hash code for this object.
no setterinherited
placehoderImage → Image?
final
placeImageSize → Size
final
pointRadius → Radius
final
pointShaderColors → List<Color>?
final
pointSize → Size
final
pointType → PointType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited