DimensionCellStyle class

Constructors

DimensionCellStyle({double tipSpace = 0, EdgeInsets padding = EdgeInsets.zero, Color borderColor = defaultColor, double borderWidth = 1, Color backgroundColor = defaultColor, Offset offset = Offset.zero, double? borderRadius})
DimensionCellStyle.only({double tipSpace = 0, EdgeInsets padding = EdgeInsets.zero, Color borderColor = defaultColor, double borderWidth = 1, Color backgroundColor = defaultColor, Offset offset = Offset.zero, double? borderRadius})
const

Properties

backgroundColor → Color
final
borderColor → Color
final
borderRadius → double?
final
borderWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipSpace → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

normal → const DimensionCellStyle