DimensionalityBean class

Constructors

DimensionalityBean({String? tagTitle, TextStyle? tagTitleStyle, double lineWidth = 0, Color lineColor = Colors.transparent, bool isHintLineImaginary = false, Color fillColor = defaultColor, required List<DimensionCellModel> tagContents, double? tagTipWidth = 15, double? tagTipHeight = 5})

Properties

fillColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isHintLineImaginary ↔ bool
getter/setter pair
lineColor ↔ Color
getter/setter pair
lineWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagContents ↔ List<DimensionCellModel>
getter/setter pair
tagTipHeight ↔ double?
getter/setter pair
tagTipWidth ↔ double?
getter/setter pair
tagTitle ↔ String?
getter/setter pair
tagTitleStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited