ChartBeanFocus class

Constructors

ChartBeanFocus({required num focus, num? focusMax, num? focusMin, int second = 0, dynamic touchBackValue, String tag = '', CellPointSet cellPointSet = CellPointSet.normal})

Properties

cellPointSet ↔ CellPointSet
getter/setter pair
focus ↔ num
getter/setter pair
focusMax ↔ num?
getter/setter pair
focusMin ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second ↔ int
getter/setter pair
tag ↔ String
getter/setter pair
touchBackValue ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited