LineSectionModel class

Constructors

LineSectionModel({Color lineSectionBorColor = Colors.purple, double borLineWidth = 1, bool isBorLineImaginary = true, List<Color>? fillColors})

Properties

borLineWidth ↔ double
getter/setter pair
fillColors ↔ List<Color>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isBorLineImaginary ↔ bool
getter/setter pair
lineSectionBorColor ↔ Color
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited