SectionBean class

Constructors

SectionBean({TextSetModel? textTitle, ImgSetModel? imgTitle, double titleBottomSpace = 0, double startRatio = 0, double widthRatio = 0, Color? fillColor, Color? borderColor, double? borderWidth = 1, bool isBorderSolid = true})

Properties

borderColor ↔ Color?
getter/setter pair
borderWidth ↔ double?
getter/setter pair
fillColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imgTitle ↔ ImgSetModel?
getter/setter pair
isBorderSolid ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startRatio ↔ double
getter/setter pair
textTitle ↔ TextSetModel?
getter/setter pair
titleBottomSpace ↔ double
getter/setter pair
widthRatio ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited