BeanDealModel class

Constructors

BeanDealModel({double? value, required double valueMax, required double valueMin, CellPointSet cellPointSet = CellPointSet.normal, String tag = '', dynamic touchBackValue})

Properties

cellPointSet ↔ CellPointSet
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String
getter/setter pair
touchBackValue ↔ dynamic
getter/setter pair
value ↔ double?
getter/setter pair
valueMax ↔ double
getter/setter pair
valueMin ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited