LineSection class

Constructors

LineSection({List<Offset>? topPoints, List<Offset>? bottomPoints})

Properties

bottomPoints ↔ List<Offset>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topPoints ↔ List<Offset>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited