ChartBeanSystem class

Constructors

ChartBeanSystem({double lineWidth = 2, bool isCurve = false, List<double>? dashArray, required List<ChartLineBean> chartBeans, LineShaderSetModel? lineShader, Color lineColor = defaultColor, Gradient? lineGradient, CellPointSet alonePointSet = CellPointSet.normal, bool enableTouch = false})

Properties

alonePointSet ↔ CellPointSet
getter/setter pair
chartBeans ↔ List<ChartLineBean>
getter/setter pair
dashArray ↔ List<double>?
getter/setter pair
enableTouch ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCurve ↔ bool
getter/setter pair
lineColor ↔ Color
getter/setter pair
lineGradient ↔ Gradient?
曲线或折线的整体绘制区域的渐变设置,如果不为空会覆盖 lineColor的设置效果,
getter/setter pair
lineShader ↔ LineShaderSetModel?
getter/setter pair
lineWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited