ChartLineBean class

Constructors

ChartLineBean({double xPositionRetioy = 0, double? y, String yShowText = '', TextStyle yShowTextStyle = defaultTextStyle, double pointToTextSpace = 0, CellPointSet cellPointSet = CellPointSet.normal, String tag = '', dynamic touchBackParam})

Properties

cellPointSet ↔ CellPointSet
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pointToTextSpace ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String
getter/setter pair
touchBackParam ↔ dynamic
getter/setter pair
xPositionRetioy ↔ double
getter/setter pair
y ↔ double?
getter/setter pair
yShowText ↔ String
getter/setter pair
yShowTextStyle ↔ TextStyle
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited