LineTouchSet class

Constructors

LineTouchSet({bool outsidePointClear = true, HintEdgeInset hintEdgeInset = HintEdgeInset.none, CellPointSet pointSet = CellPointSet.normal, PointPressPointBack? touchBack})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hintEdgeInset ↔ HintEdgeInset
getter/setter pair
outsidePointClear ↔ bool
getter/setter pair
pointSet ↔ CellPointSet
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
touchBack ↔ PointPressPointBack?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited