LinePointModel class

Constructors

LinePointModel({required double x, double? y, String text = '', TextStyle textStyle = defaultTextStyle, double pointToTextSpace = 0, CellPointSet cellPointSet = CellPointSet.normal})

Properties

cellPointSet ↔ CellPointSet
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pointToTextSpace ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
textStyle ↔ TextStyle
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited