ChartPieBean class

Constructors

ChartPieBean({required double value, String type = '', Color color = defaultColor, TextStyle assistTextStyle = defaultTextStyle})

Properties

assistTextStyle ↔ TextStyle
getter/setter pair
color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
value ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited