RedrawModel class

内部使用

Constructors

RedrawModel({required Point<num> rowTopPoint, required Point<num> rectTopLeftPoint, required TextPainter textPainter, bool isAdjust = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAdjust ↔ bool
getter/setter pair
rectTopLeftPoint ↔ Point<num>
getter/setter pair
rowTopPoint ↔ Point<num>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textPainter ↔ TextPainter
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited