CoordinateAxisModel class

绘制xy轴的额所需参数设置

Constructors

CoordinateAxisModel(double fixedHeight, double fixedWidth, {required BaseBean baseBean, required List<DialStyleX> xDialValues, XYCoordinate xyCoordinate = XYCoordinate.All, double bothEndPitchX = 0})

Properties

baseBean ↔ BaseBean
getter/setter pair
bothEndPitchX ↔ double
getter/setter pair
fixedHeight ↔ double
getter/setter pair
fixedWidth ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xDialValues ↔ List<DialStyleX>
getter/setter pair
xyCoordinate ↔ XYCoordinate
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited