AnimationSet class

Constructors

AnimationSet({int animationDuration = 0, VoidCallback? onAnimationEnd, Widget? widgetIndicator, bool restartAnimation = false, bool animateFromLastPercent = false, Curve curve = Curves.linear})
AnimationSet.normalSet()
const

Properties

animateFromLastPercent → bool
让动画从上次的百分比开始
final
animationDuration → int
动画的时长, 单位milliseconds
final
curve → Curve
set a linear curve animation type
final
hashCode → int
The hash code for this object.
no setterinherited
onAnimationEnd → VoidCallback?
动画结束回调
final
restartAnimation → bool
是否无限重复动画 默认 false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgetIndicator → Widget?
当动画开启的时候,放置在动画进度的位置的一个指示器
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

normal → const AnimationSet